@@ -1,11 +1,9 @@
-#ifndef DIMPROCS_H
-#define DIMPROCS_H
-
 /*
-  Copyright (c) 1998 - 2013
+  Copyright (c) 2006 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of dimbl
 
   dimbl is free software; you can redistribute it and/or modify
@@ -22,19 +20,22 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/dimbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
+#ifndef DIMPROCS_H
+#define DIMPROCS_H
 
 #include <cstring>
 #include <iomanip>
 #include <unistd.h> // for unlink()
+#include "ticcutils/StringOps.h"
 #include "timbl/Statistics.h"
 
 class settings {
  public:
-  settings( Timbl::TimblOpts& );
+  settings( TiCC::CL_Options& );
   ~settings(){ delete distanceMetric; };
   bool ok() const { return status; };
   int numThreads;
@@ -44,7 +45,9 @@ class settings {
   std::string treeOutFileName;
   std::string treeInFileName;
   std::string outFileName;
+  std::string tmpdir;
   bool wFileSpecified;
+  bool keepfiles;
   mutable std::ifstream inp;
   mutable std::ofstream out;
   Timbl::decayStruct *distanceMetric;
@@ -77,14 +80,14 @@ protected:
   const Timbl::neighborSet *result;
 };
 
-void split( const std::string& , int );
+void split( const std::string& , int, const std::string& );
 void time_stamp( std::ostream&, const std::string&, int = -1 );
 
 
 template <class working>
 class experiment {
  public:
- experiment( Timbl::TimblOpts& opts ): config( opts ){
+ experiment( TiCC::CL_Options& opts ): config( opts ){
     if ( !config.ok() ){
       throw std::runtime_error( "error in config" );
     }
@@ -94,9 +97,9 @@ class experiment {
     targets = 0;
   }
   virtual ~experiment();
-  bool Train( Timbl::TimblOpts& );
+  bool Train( const TiCC::CL_Options& );
   virtual bool createWorkers();
-  virtual bool createWorkersFromFile( Timbl::TimblOpts& );
+  virtual bool createWorkersFromFile( const TiCC::CL_Options& );
   virtual bool createWorkerFiles();
   Timbl::neighborSet Finalize();
   void showResult( Timbl::neighborSet&, const std::string& );
@@ -114,26 +117,33 @@ class experiment {
 
 template <class working>
 experiment<working>::~experiment() {
-  std::cout << "cleanup intermediate files " << std::endl;
-  for( int i=0; i < size; ++i ){
-    std::string iname = config.trainFileName + "-" + TiCC::toString( i+1 );
-    unlink( iname.c_str() );
+  if ( !config.keepfiles
+       && config.treeInFileName.empty() ){
+    std::cout << "cleanup intermediate files in " << config.tmpdir << std::endl;
+    for( int i=0; i < size; ++i ){
+      std::string iname = config.tmpdir
+	+ TiCC::basename(config.trainFileName) + "-" + TiCC::toString( i+1 );
+      unlink( iname.c_str() );
+    }
   }
   children.clear();
   delete train;
 }
 
 template <class working>
-bool experiment<working>::Train( Timbl::TimblOpts& opts ){
+bool experiment<working>::Train( const TiCC::CL_Options& opts ){
   bool ok = true;
-  train = new Timbl::TimblAPI( &opts, "train" );
+  train = new Timbl::TimblAPI( opts, "train" );
   if ( !train ){
     throw std::runtime_error( "training failed" );
   }
-  time_stamp( std::cout, "learning using '" + config.trainFileName + "':" );
+  time_stamp( std::cout,
+	      "learning using '"
+	      + TiCC::basename(config.trainFileName)
+	      + "':" );
   ok = train->Learn( config.trainFileName );
   if ( !config.weightsFileName.empty() ){
-    //     std::cout << "saving weights in '"  
+    //     std::cout << "saving weights in '"
     // 	      << config.weightsFileName << "'" << std::endl;
     ok = train->SaveWeights( config.weightsFileName );
   }
@@ -159,7 +169,7 @@ Timbl::neighborSet experiment<working>::Finalize(){
 }
 
 template <class working>
-void experiment<working>::showResult( Timbl::neighborSet& res, 
+void experiment<working>::showResult( Timbl::neighborSet& res,
 				      const std::string& orig ){
   if ( res.size() == 0 ){
     config.out << orig << " FAILED TEST" << std::endl;
@@ -246,8 +256,8 @@ void experiment<working>::showStatistics( std::ostream& os ) const {
   os << std::endl;
   if ( confusion )
     confusion->FScore( os, targets, config.do_class_stats );
-  os << "overall accuracy:        " 
-     << stats.testedCorrect()/(double) stats.dataLines() 
+  os << "overall accuracy:        "
+     << stats.testedCorrect()/(double) stats.dataLines()
      << "  (" << stats.testedCorrect() << "/" << stats.dataLines()  << ")" ;
   if ( stats.exactMatches() != 0 )
     os << ", of which " << stats.exactMatches() << " exact matches " ;
@@ -276,7 +286,7 @@ void experiment<working>::showStatistics( std::ostream& os ) const {
 }
 
 template <class working>
-void experiment<working>::showProgress( std::ostream& os, 
+void experiment<working>::showProgress( std::ostream& os,
 					int line, time_t start ){
   char time_string[26];
   struct tm *curtime;
@@ -285,7 +295,7 @@ void experiment<working>::showProgress( std::ostream& os,
   time_t EstimatedTime;
   double Estimated;
   int local_progress = config.progress;
-  
+
   if ( ( (line % local_progress ) == 0) || ( line <= 10 ) ||
 	 ( line == 100 || line == 1000 || line == 10000 ) ){
     time(&Time);
@@ -307,20 +317,20 @@ void experiment<working>::showProgress( std::ostream& os,
     strcpy( time_string, asctime(curtime));
     time_string[24] = '\0';
     os << line << " @ " << time_string;
-    
+
     // Estime time until Estimate.
     //
     if ( config.estimate > 0 ) {
       SecsUsed = Time - start;
       if ( SecsUsed > 0 ) {
-	Estimated = (SecsUsed / (float)line) * 
+	Estimated = (SecsUsed / (float)line) *
 	  (float)config.estimate;
 	EstimatedTime = (long)Estimated + start;
 	os << ", ";
 	strcpy(time_string, ctime(&EstimatedTime));
 	time_string[24] = '\0';
 	os << config.estimate << ": " << time_string;
-      } 
+      }
     }
     os << std::endl;
   }
