@@ -1,8 +1,9 @@
 /*
-  Copyright (c) 1998 - 2013
+  Copyright (c) 2006 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of dimbl
 
   dimbl is free software; you can redistribute it and/or modify
@@ -19,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/dimbl/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #include <ostream>
@@ -42,7 +44,7 @@ worker::~worker(){
     delete exp;
 }
 
-void split( const string& file, int num ){
+void split( const string& file, int num, const string& tmpdir ){
   int cnt=0;
   string line;
   ifstream is( file.c_str() );
@@ -53,7 +55,7 @@ void split( const string& file, int num ){
     is.seekg(0);
     int to_do = cnt/num + 1;
     for ( int i=0; i < num; ++i ){
-      string oname = file + "-" + toString( i+1 );
+      string oname = tmpdir + TiCC::basename(file) + "-" + toString( i+1 );
       ofstream os( oname.c_str() );
       if ( os ){
 	int done = 0;
@@ -72,7 +74,7 @@ void split( const string& file, int num ){
   }
 }
 
-settings::settings( TimblOpts& Opts ){
+settings::settings( TiCC::CL_Options& opts ){
   status = true;
   wFileSpecified=false;
   distanceMetric = 0;
@@ -88,61 +90,61 @@ settings::settings( TimblOpts& Opts ){
   progress = 10000;
   estimate = 0;
   IF = UnknownInputFormat;
-  bool mood;
+  tmpdir = "/tmp/";
+  keepfiles = false;
   string value;
-  if ( Opts.Find( 'a', value, mood ) ){
+  if ( opts.is_present( 'a', value ) ){
     Algorithm tst;
     if ( !string_to(value,tst) || tst != IB1 ){
       cerr << "unsupported algorithm. only IB1 is possible!" << endl;
       status = false;
     }
   }
-  if ( Opts.Find( 'S', value, mood ) ){
+  if ( opts.extract( 'S', value ) ){
     numThreads = stringTo<int>( value );
-    Opts.Delete( 'S' );
   }
-  if ( Opts.Find( 'k', value, mood ) ){
+  if ( opts.extract( 'k', value ) ){
     nn = stringTo<int>(value) + 1;
-    Opts.Delete( 'k' );
   }
-  Opts.Add( 'k', toString<int>( nn ), true );
-  if ( Opts.Find( "Beam", value, mood ) ){
+  opts.insert( 'k', toString<int>( nn ), true );
+  if ( opts.extract( "Beam", value ) ){
     beam = stringTo<int>(value);
-    Opts.Delete( "Beam" );
   }
-  if ( Opts.Find( 'e', value, mood ) ){
+  if ( opts.extract( "tempdir", value ) ){
+    tmpdir = value;
+    if ( !tmpdir.empty() && tmpdir[tmpdir.length()-1] != '/' ){
+      tmpdir += "/";
+    }
+  }
+  if ( opts.extract( "keep", value ) ){
+    keepfiles = true;
+  }
+  if ( opts.extract( 'e', value ) ){
     estimate = stringTo<int>(value);
-    Opts.Delete( 'e' );
   }
-  if ( Opts.Find( 'F', value, mood ) ){
+  if ( opts.is_present( 'F', value ) ){
     if ( !stringTo<InputFormatType>( value, IF ) ){
       cerr << "illegal value for -F option: " << value << endl;
       status = false;
     }
-  }	
-  if ( Opts.Find( 'p', value, mood ) ){
+  }
+  if ( opts.extract( 'p', value ) ){
     progress = stringTo<int>(value);
-    Opts.Delete( 'p' );
   }
-  if ( Opts.Find( 'f', value, mood ) ){
+  if ( opts.extract( 'f', value ) ){
     trainFileName = value;
-    Opts.Delete( 'f' );
   }
-  if ( Opts.Find( 't', value, mood ) ){
+  if ( opts.extract( 't', value ) ){
     testFileName = value;
-    Opts.Delete( 't' );
   }
-  if ( Opts.Find( 'i', value, mood ) ){
+  if ( opts.extract( 'i', value ) ){
     treeInFileName = value;
-    Opts.Delete( 'i' );
   }
-  if ( Opts.Find( 'I', value, mood ) ){
+  if ( opts.extract( 'I', value ) ){
     treeOutFileName = value;
-    Opts.Delete( 'I' );
   }
-  if ( Opts.Find( 'o', value, mood ) ){
+  if ( opts.extract( 'o', value ) ){
     outFileName = value;
-    Opts.Delete( 'o' );
   }
   else
     outFileName = testFileName + ".out";
@@ -156,7 +158,7 @@ settings::settings( TimblOpts& Opts ){
   }
   else {
     Weighting W = GR;
-    if ( Opts.Find( 'w', value, mood ) ){
+    if ( opts.is_present( 'w', value ) ){
       // user specified weighting
       if ( !string_to( value, W ) ){
 	// No valid weighting, so assume it also has a filename
@@ -170,15 +172,15 @@ settings::settings( TimblOpts& Opts ){
 	  if ( status ){
 	    weightsFileName = parts[0];
 	    wFileSpecified = true;
-	    Opts.Delete( 'w' );
+	    opts.remove( 'w' );
 	  }
 	}
 	else if ( num == 1 ){
 	  weightsFileName = value;
 	  wFileSpecified = true;
 	  W = GR;
-	  Opts.Delete( 'w' );
-	} 
+	  opts.remove( 'w' );
+	}
 	else {
 	  cerr << "invalid weighting option: " << value << endl;
 	  status = false;
@@ -186,18 +188,18 @@ settings::settings( TimblOpts& Opts ){
       }
       else {
 	// valid Weight, but maybe a number, so replace anyway
-	Opts.Delete( 'w' );
+	opts.remove( 'w' );
       }
       if ( trainFileName.empty() && !weightsFileName.empty() ){
 	cerr << "a weights filename is specied. "
 	     << "That is incompatible with the -i option" << endl;
 	status = false;
       }
-      Opts.Add( 'w', to_string(W), false );
+      opts.insert( 'w', to_string(W), false );
     }
   }
   if ( status ) {
-    if ( Opts.Find( 'd', value, mood ) ){
+    if ( opts.extract( 'd', value ) ){
       // user specified distance metric
       DecayType decay = UnknownDecay;
       double decay_alfa = 1.0;
@@ -224,7 +226,7 @@ settings::settings( TimblOpts& Opts ){
 	  if ( pos2 != string::npos ){
 	    if ( ! ( stringTo<DecayType>( string( value, 0, pos1 ),
 					  decay ) &&
-		     stringTo<double>( string( value, pos2 ), 
+		     stringTo<double>( string( value, pos2 ),
 				       decay_alfa ) ) ){
 	      cerr << "illegal value for -d option: " << value << endl;
 	      status = false;
@@ -237,9 +239,9 @@ settings::settings( TimblOpts& Opts ){
 	}
 	else {
 	  if ( ! ( stringTo<DecayType>( string( value, 0, pos1 ), decay ) &&
-		   stringTo<double>( string( value, pos1+1, pos2-pos1-1 ), 
+		   stringTo<double>( string( value, pos1+1, pos2-pos1-1 ),
 				     decay_alfa ) &&
-		   stringTo<double>( string( value, pos2+1 ), 
+		   stringTo<double>( string( value, pos2+1 ),
 				     decay_beta ) ) ){
 	    cerr << "illegal value for -d option: " << value << endl;
 	    status = false;
@@ -263,12 +265,12 @@ settings::settings( TimblOpts& Opts ){
 	default:
 	  cerr << "ignoring unknown decay" << toString( decay ) << endl;
 	}
-	Opts.Delete( 'd' );
       }
     }
   }
   if ( status ){
-    if ( Opts.Find( 'v', value, mood ) ){
+    bool mood;
+    if ( opts.extract( 'v', value, mood ) ){
       if ( value.find( "di" ) != string::npos )
 	do_distance = true;
       if ( value.find( "db" ) != string::npos )
@@ -285,9 +287,8 @@ settings::settings( TimblOpts& Opts ){
       }
       if ( value.find( "as" ) != string::npos )
 	do_advanced_stats = true;
-      Opts.Delete( 'v' );
     }
-    Opts.Add( 'v', "S", true );
+    opts.insert( 'v', "S", true );
     if ( treeOutFileName.empty() ){
       inp.open( testFileName.c_str() );
       if ( !inp ){
@@ -312,7 +313,7 @@ inline string curTime(){
   time_string = asctime(curtime);
   time_string[24] = '\0'; // defeat the newline!
   return time_string;
-}  
+}
 
 void time_stamp( ostream& os, const string& line, int number ) {
   os << line;
@@ -325,8 +326,8 @@ void time_stamp( ostream& os, const string& line, int number ) {
     os << "        ";
   os << curTime() << endl;
 }
-  
-void show_speed_summary( ostream& os, int lines, 
+
+void show_speed_summary( ostream& os, int lines,
 			 const timeval& Start ) {
   timeval Time;
   gettimeofday( &Time, 0 );
@@ -341,4 +342,3 @@ void show_speed_summary( ostream& os, int lines,
   os << lines / secsUsed << " p/s)" << endl;
   os << setprecision(oldPrec);
 }
-
